==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXEvent.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXEvent;no warnings;($__userLogoutOnWindowsStarted=(0x1ad5+  15-0x1ae4))
;sub handleEvent{(my $eventCode=shift (@_));(my $message=shift (@_));
Logger::debug ((((("\x48\x61\x6e\x64\x6c\x65\x20\x65\x76\x65\x6e\x74\x20\x27".
$eventCode)."\x27\x20\x27").$message)."\x27\x2e"));if (($events{$eventCode}ne 
(""))){(my $func=$events{$eventCode});Logger::debug ((((
"\x48\x61\x6e\x64\x6c\x65\x20\x65\x76\x65\x6e\x74\x3a\x20\x67\x6f\x69\x6e\x67\x20\x74\x6f\x20\x63\x61\x6c\x6c\x20\x66\x75\x6e\x63\x74\x69\x6f\x6e\x3a\x20"
.$func).
"\x20\x66\x6f\x72\x20\x68\x61\x6e\x64\x6c\x69\x6e\x67\x20\x65\x76\x65\x6e\x74\x20\x77\x69\x74\x68\x20\x63\x6f\x64\x65\x3a\x20"
).$eventCode));return (&$func ($message));}else{Logger::debug (((
"\x48\x61\x6e\x64\x6c\x65\x20\x65\x76\x65\x6e\x74\x3a\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x20\x65\x76\x65\x6e\x74\x20\x68\x61\x6e\x64\x6c\x65\x20\x66\x6f\x72\x20"
.$eventCode)."\x2e"));}}sub beforeSessionStart{
VirtualSessions::initializeKerberosTicketWhenNeeded ();main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_before_start_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x73\x74\x61\x72\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionStart{if (Common::NXSessionType::isVirtual (
NXSession::getSessionType ())){VirtualSessions::setSessionStarted ();}
main::nxrequire ("\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_after_start_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x73\x74\x61\x72\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub beforeSessionReconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_before_session_reconnecting ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionReconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_after_session_reconnecting ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub beforeSessionDisconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (NXScripts::script_before_suspend ())
{(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x64\x69\x73\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionDisconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (NXScripts::script_after_suspend ()){
(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x64\x69\x73\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub beforeSessionClose{NXSession::setSessionCloseStarted ();
VirtualSessions::removeKerberosTicketWhenNeeded ();main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_before_close_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x63\x6c\x6f\x73\x65\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionClose{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_after_close_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x63\x6c\x6f\x73\x65\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionFailure{VirtualSessions::removeKerberosTicketWhenNeeded ();
main::nxrequire ("\x4e\x58\x53\x63\x72\x69\x70\x74\x73");
NXScripts::script_after_session_failure ();}sub afterRemoteResize{
main::nxrequire ("\x4e\x58\x53\x63\x72\x69\x70\x74\x73");(my $width=shift (@_));
(my $height=shift (@_));if (NXScripts::script_after_remote_resize ($width,
$height)){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x72\x65\x6d\x6f\x74\x65\x20\x72\x65\x73\x69\x7a\x65\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);if (
Common::NXSessionType::isNotPhysical (NXSession::getSessionType ())){
main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}}sub afterLocalSessionClose{
NXLocalSession::logoutOrLockScreenBeforeTerminateIfNeeded ();}sub 
afterLocalSessionFailure{
NXLocalSession::logoutOrLockScreenBeforeTerminateIfNeeded ();}sub 
desktopUserLogoutOnWindows{setDesktopUserLogoutOnWindowsStarted ();
NXLocalSession::setLockScreenBeforeTerminateDisabled ();}sub 
setDesktopUserLogoutOnWindowsStarted{($__userLogoutOnWindowsStarted=
(0x170d+ 2321-0x201d));}sub userLogoutOnWindowsStarted{return (
$__userLogoutOnWindowsStarted);}"\x3f\x3f\x3f";

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXEvent.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXEvent;no warnings;($__userLogoutOnWindowsStarted=(0x1d99+ 1303-0x22b0)
);sub handleEvent{(my $eventCode=shift (@_));(my $message=shift (@_));
Logger::debug ((((("\x48\x61\x6e\x64\x6c\x65\x20\x65\x76\x65\x6e\x74\x20\x27".
$eventCode)."\x27\x20\x27").$message)."\x27\x2e"));if (($events{$eventCode}ne 
(""))){(my $func=$events{$eventCode});Logger::debug ((((
"\x48\x61\x6e\x64\x6c\x65\x20\x65\x76\x65\x6e\x74\x3a\x20\x67\x6f\x69\x6e\x67\x20\x74\x6f\x20\x63\x61\x6c\x6c\x20\x66\x75\x6e\x63\x74\x69\x6f\x6e\x3a\x20"
.$func).
"\x20\x66\x6f\x72\x20\x68\x61\x6e\x64\x6c\x69\x6e\x67\x20\x65\x76\x65\x6e\x74\x20\x77\x69\x74\x68\x20\x63\x6f\x64\x65\x3a\x20"
).$eventCode));return (&$func ($message));}else{Logger::debug (((
"\x48\x61\x6e\x64\x6c\x65\x20\x65\x76\x65\x6e\x74\x3a\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x20\x65\x76\x65\x6e\x74\x20\x68\x61\x6e\x64\x6c\x65\x20\x66\x6f\x72\x20"
.$eventCode)."\x2e"));}}sub beforeSessionStart{
VirtualSessions::initializeKerberosTicketWhenNeeded ();main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_before_start_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x73\x74\x61\x72\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionStart{if (Common::NXSessionType::isVirtual (
NXSession::getSessionType ())){VirtualSessions::setSessionStarted ();}
main::nxrequire ("\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_after_start_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x73\x74\x61\x72\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub beforeSessionReconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_before_session_reconnecting ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionReconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_after_session_reconnecting ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub beforeSessionDisconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (NXScripts::script_before_suspend ())
{(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x64\x69\x73\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionDisconnect{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (NXScripts::script_after_suspend ()){
(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x64\x69\x73\x63\x6f\x6e\x6e\x65\x63\x74\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub beforeSessionClose{NXSession::setSessionCloseStarted ();
VirtualSessions::removeKerberosTicketWhenNeeded ();main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_before_close_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x62\x65\x66\x6f\x72\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x63\x6c\x6f\x73\x65\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionClose{main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");if (
NXScripts::script_after_close_session ()){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x63\x6c\x6f\x73\x65\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}sub afterSessionFailure{VirtualSessions::removeKerberosTicketWhenNeeded ();
main::nxrequire ("\x4e\x58\x53\x63\x72\x69\x70\x74\x73");
NXScripts::script_after_session_failure ();}sub afterRemoteResize{
main::nxrequire ("\x4e\x58\x53\x63\x72\x69\x70\x74\x73");(my $width=shift (@_));
(my $height=shift (@_));if (NXScripts::script_after_remote_resize ($width,
$height)){(my $errorMessage=
"\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x20\x6f\x66\x20\x63\x75\x73\x74\x6f\x6d\x20\x73\x63\x72\x69\x70\x74\x20\x66\x61\x69\x6c\x65\x64\x20\x6f\x6e\x20\x65\x76\x65\x6e\x74\x20\x27\x61\x66\x74\x65\x72\x20\x72\x65\x6d\x6f\x74\x65\x20\x72\x65\x73\x69\x7a\x65\x27\x2e"
);main::nxwrite (main::nxgetSTDERR (),(("\x45\x72\x72\x6f\x72\x3a\x20".
$errorMessage)."\x0a"));Logger::error ($errorMessage);if (
Common::NXSessionType::isNotPhysical (NXSession::getSessionType ())){
main::clean_and_die (
"\x65\x45\x78\x65\x63\x75\x74\x69\x6f\x6e\x53\x63\x72\x69\x70\x74\x46\x61\x69\x6c\x65\x64"
);}}}sub afterLocalSessionClose{
NXLocalSession::logoutOrLockScreenBeforeTerminateIfNeeded ();}sub 
afterLocalSessionFailure{
NXLocalSession::logoutOrLockScreenBeforeTerminateIfNeeded ();}sub 
desktopUserLogoutOnWindows{setDesktopUserLogoutOnWindowsStarted ();
NXLocalSession::setLockScreenBeforeTerminateDisabled ();}sub 
setDesktopUserLogoutOnWindowsStarted{($__userLogoutOnWindowsStarted=
(0x0fdb+ 660-0x126e));}sub userLogoutOnWindowsStarted{return (
$__userLogoutOnWindowsStarted);}"\x3f\x3f\x3f";
